; docformat = 'rst'
;+
; This is an example program to demonstrate how to create a histogram plot with some of it features
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "histo_plot.pro" and run it like this::
;       IDL> .RUN histo_plot
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Histo_Plot
 
   ; Example data. Normally passed into the program as a positional parameter.
   data = cgDemoData(7)
   
   ; Create the histogram plot. Use histogram frequency, instead of
   ; histogram density, and overplot the cumulative probability curve.
   cgDisplay
   thick = (!D.Name EQ 'PS') ? 6 : 3
   cgHistoplot, data, /Frequency, /OProbability, ProbColor='red', $
      ProbThick=thick, PolyColor='dodger blue', /FillPolygon, DataColor='navy'
      
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Histo_Plot
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Histo_Plot', WBackground='White', $
     WTitle='Histogram Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'histo_plot.ps'
  Histo_Plot
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'histo_plot.ps', /PNG, Width=600

END